==> 1.2.3.tar.gz: lib/src/transitions/parallax_transition.dart <==
import 'package:cruiser/src/models/cruiser_transition.dart';
import 'package:flutter/widgets.dart';

class ParallaxTransition extends CruiserTransition
{
    final Curve curve;
    final double offset;

    ParallaxTransition({
        this.curve = Curves.easeOutSine,
        this.offset = 0.2,
    });

    @override
    Widget build(BuildContext context,  Animation<double> primaryAnimation, Animation<double> secondaryAnimation, Widget child)
    {
        var exitAnimation = secondaryAnimation as ProxyAnimation;

        double width = MediaQuery.of(context).size.width;

        if(!exitAnimation.isDismissed)
        {
            var animation = CurvedAnimation(parent: secondaryAnimation, curve: curve);

            return Transform(
                transform: Matrix4.identity()..translate(-width * animation.value),
                child: child,
            );
        }
        else
        {
            var animation = CurvedAnimation(parent: primaryAnimation, curve: curve);

            return ClipRect(
                clipper: ParallaxClipper(value: animation.value),
                child: Transform(
                    transform: Matrix4.identity()
                    ..translate(width * offset * (1.0 - animation.value)),
                    child: child,
            ));
        }
    }
}

class ParallaxClipper extends CustomClipper<Rect> 
{
    final double value;

    ParallaxClipper({this.value});

    @override
    Rect getClip(Size size) {
        return Rect.fromLTRB(size.width * (1 - value), 0, size.width, size.height);
    }

    @override
    bool shouldReclip(CustomClipper<Rect> oldClipper)
    {
        return true;
    }
}

==> 2.0.1.tar.gz: lib/src/transitions/parallax_transition.dart <==
import 'package:cruiser/src/models/cruiser_transition.dart';
import 'package:flutter/widgets.dart';

class ParallaxTransition extends CruiserTransition
{
    final Curve curve;
    final double offset;

    ParallaxTransition({
        this.curve = Curves.easeOutSine,
        this.offset = 0.2,
    });

    @override
    Widget build(BuildContext context,  Animation<double> primaryAnimation, Animation<double> secondaryAnimation, Widget child)
    {
        var exitAnimation = secondaryAnimation as ProxyAnimation;

        double width = MediaQuery.of(context).size.width;

        if(!exitAnimation.isDismissed)
        {
            var animation = CurvedAnimation(parent: secondaryAnimation, curve: curve);

            return Transform(
                transform: Matrix4.identity()..translate(-width * animation.value),
                child: child,
            );
        }
        else
        {
            var animation = CurvedAnimation(parent: primaryAnimation, curve: curve);

            return ClipRect(
                clipper: ParallaxClipper(value: animation.value),
                child: Transform(
                    transform: Matrix4.identity()
                    ..translate(width * offset * (1.0 - animation.value)),
                    child: child,
            ));
        }
    }
}

class ParallaxClipper extends CustomClipper<Rect> 
{
    final double value;

    ParallaxClipper({required this.value});

    @override
    Rect getClip(Size size) {
        return Rect.fromLTRB(size.width * (1 - value), 0, size.width, size.height);
    }

    @override
    bool shouldReclip(CustomClipper<Rect> oldClipper)
    {
        return true;
    }
}
